==> apache-camel-4.0.6-src.zip: apache-camel-4.0.6/core/camel-core/src/test/java/org/apache/camel/issues/StopRouteShouldNotStopRouteScopedErrorHandlerIssueTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class StopRouteShouldNotStopRouteScopedErrorHandlerIssueTest extends ContextTestSupport {

    @Test
    public void testIssue() throws Exception {
        getMockEndpoint("mock:error").expectedMessageCount(1);

        // stopping foo route, which should not stop context scoped error
        // handler
        context.getRouteController().stopRoute("foo");

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").routeId("start")
                        // use context scoped
                        .errorHandler(deadLetterChannel("mock:error").maximumRedeliveries(0)).to("log:start")
                        .throwException(new IllegalArgumentException("Forced"));

                from("direct:foo").routeId("foo").to("log:foo").to("mock:foo");
            }
        };
    }

}

==> apache-camel-4.14.4-src.zip: apache-camel-4.14.4/core/camel-core/src/test/java/org/apache/camel/issues/StopRouteShouldNotStopRouteScopedErrorHandlerIssueTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.issues;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class StopRouteShouldNotStopRouteScopedErrorHandlerIssueTest extends ContextTestSupport {

    @Test
    public void testIssue() throws Exception {
        getMockEndpoint("mock:error").expectedMessageCount(1);

        // stopping foo route, which should not stop context scoped error
        // handler
        context.getRouteController().stopRoute("foo");

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start").routeId("start")
                        // use context scoped
                        .errorHandler(deadLetterChannel("mock:error").maximumRedeliveries(0)).to("log:start")
                        .throwException(new IllegalArgumentException("Forced"));

                from("direct:foo").routeId("foo").to("log:foo").to("mock:foo");
            }
        };
    }

}
